# $Id: en_us.pm 507 2005-06-08 03:17:04Z claco $
package Handel::L10N::en_us;
use strict;
use warnings;
use utf8;
use vars qw(%Lexicon);

BEGIN {
    use base 'Handel::L10N';
};

%Lexicon = (
    Language => 'English',
);

1;
__END__

=head1 NAME

Handel::L10N::en_us - Handel Language Pack: US English

=head1 AUTHOR

    Christopher H. Laco
    CPAN ID: CLACO
    claco@chrislaco.com
    http://today.icantfocus.com/blog/